# Machine Learning on EIS

## Project Objectives:


### Current Functionality:
Our results are presented in the user interface called echem_pred. This UI has the following functionalities:
* Data visualization:
- [x] EIS plotting
- [x] dqdv
- [x] Battery cycling plotting

* Machine Learning:
Our machine learning has two different modes: online training and offline training. Online training includes.... while offline training uses developed....
- [ ] Offline data training
- [ ] Online data training 
    - [ ] Decision Tree
    - [ ]   
    - [ ]   

## Modules Overview:

* echem_pred.py: Main file for the user interface. Including three main parts: main window, data visualization (window 2), and machine learning (window 3).

## Software Tutorial:

After cloning this repo annd installing the requirements, the Echem Visualizer App can be used to interact the xx functions to visualize cycling data. 

To start the app please run....:

After running, the main page should look like this:



## Installation:
### Environment:
(What's the required environment)

### Instruction:
(How to install)

## Acknowledgement:
